/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.web.url.apio.internal.architect.resource;

import com.liferay.apio.architect.functional.Try;
import com.liferay.apio.architect.representor.Representor;
import com.liferay.apio.architect.resource.ItemResource;
import com.liferay.apio.architect.routes.ItemRoutes;
import com.liferay.portal.kernel.model.ListType;
import com.liferay.portal.kernel.model.Website;
import com.liferay.portal.kernel.service.WebsiteService;
import com.liferay.web.url.apio.architect.identifier.WebUrlIdentifier;

import org.osgi.service.component.annotations.Component;
import org.osgi.service.component.annotations.Reference;

/**
 * Provides the information necessary to expose {@code WebSite} resources
 * through a web API.
 *
 * @author Javier Gamarra
 * @review
 */
@Component(immediate = true)
public class WebUrlCollectionResource
	implements ItemResource<Website, Long, WebUrlIdentifier> {

	@Override
	public String getName() {
		return "web-urls";
	}

	@Override
	public ItemRoutes<Website, Long> itemRoutes(
		ItemRoutes.Builder<Website, Long> builder) {

		return builder.addGetter(
			_websiteService::getWebsite
		).build();
	}

	@Override
	public Representor<Website> representor(
		Representor.Builder<Website, Long> builder) {

		return builder.types(
			"Web"
		).identifier(
			Website::getWebsiteId
		).addString(
			"type",
			website -> Try.fromFallible(
				website::getType
			).map(
				ListType::getName
			).orElse(
				null
			)
		).addString(
			"url", Website::getUrl
		).build();
	}

	@Reference
	private WebsiteService _websiteService;

}